#!/bin/bash
#
# Service script for XRootD caching services
# ----------------------------------------

# Service instance name
INSTANCE="XRootD"

# XRootD installation path
XRD_PATH=/opt/XRootD

# XRootD config path
CONFIG='/opt/XRootD/configs/xrootd.cf'

# XRootD logging directory
LOGDIR='/var/log/XRootD'

# Service PID file
PIDFILE=/var/run/xrootd.pid

# Adding libraries to enironment variable
#export LD_LIBRARY_PATH=$XRD_PATH/xrd-install/lib64:$LD_LIBRARY_PATH
#export PATH=$XRD_PATH/xrd-install/bin:$PATH

ACTION=''

while getopts 'a:c:l:p:' flag; do
  case "${flag}" in
    a) ACTION="${OPTARG}" ;;
    c) CONFIG="${OPTARG}" ;;
    l) LOGDIR="${OPTARG}" ;;
    p) PIDFILE="${OPTARG}" ;;
    *) error "Unexpected option ${flag}" ;;
  esac
done

mkdir -p $LOGDIR

# Starting command for XRootD services
XROOTD_COMMAND='xrootd -c '$CONFIG' -l '$LOGDIR'/xrootd.log -k 100m &'
CMSD_COMMAND='cmsd -c '$CONFIG' -l '$LOGDIR'/cmsd.log -k 100m &'

# Check for running service processes
if [ -f $PIDFILE ]
then
        PID=`cat $PIDFILE`
fi

case "$ACTION" in
'start')
                if [ -f $PIDFILE ] ; then
                                if test `ps -e | grep -c $PID` = 1; then
                                                echo "Not starting $INSTANCE - instance already running with PID: $PID"
                                else
                                                echo "Starting $INSTANCE"
                                                echo "Starting $INSTANCE" > $LOGDIR/service.log
                                                cd $XRD_PATH
                                                nohup $XROOTD_COMMAND &>> $LOGDIR/service.log &
                                                nohup $CMSD_COMMAND &>> $LOGDIR/service.log &
                                                echo $! > $PIDFILE
                                fi
                else
                                echo "Starting $INSTANCE"
                                echo "Starting $INSTANCE" > $LOGDIR/service.log
                                cd $XRD_PATH
                                nohup $XROOTD_COMMAND &>> $LOGDIR/service.log &
                                nohup $CMSD_COMMAND &>> $LOGDIR/service.log &
                                echo $! > $PIDFILE
                fi
                ;;

'stop')
                if [ -f $PIDFILE ] ; then
                                echo "stopping $INSTANCE"
                                echo "stopping $INSTANCE" >> $LOGDIR/service.log
                                kill -15 $PID
                else
                                echo "Cannot stop $INSTANCE - no Pidfile found!"
                fi
                ;;

'restart')
                $0 -a stop -l $LOGDIR -c $CONFIG
                sleep 5
                $0 -a start -l $LOGDIR -c $CONFIG
                ;;

'status')
                if [ -f $PIDFILE ] ; then
                                if test `ps -e | grep -c $PID` = 0; then
                                                echo "$INSTANCE not running"
                                else
                                                echo "$INSTANCE running with PID: [$PID]"
                                fi
                else
                                echo "$PIDFILE does not exist! Cannot process $INSTANCE status!"
                                exit 1
                fi
                ;;

*)
                echo "usage: $0 { start | stop | restart | status }"
                ;;

esac
exit 0

